# Toolboxes

This section is WIP.

[Cedalion's name ist based on a greek myth](https://en.wikipedia.org/wiki/Cedalion): Cedalion stands on the shoulders of the giant Orion to guide him to the east, where the rays of Helios restored his sight. This toolbox stands on the shoulders of many giants, and we aim to complement existing toolboxes and packages in the community by interfacing with them wherever possible. 

A part of the core set of Cedalion's scientific fNIRS processing functionality is based on the matlab toolboxes [Homer2/3](https://github.com/BUNPC/Homer3) and [AtlasViewer](https://github.com/BUNPC/AtlasViewer) from which we have adopted methods into the python ecosystem.

## Current toolboxes cedalion interfaces with
- [Monte Carlo Xtreme](http://mcx.space/), for Monte-Carlo-based photon simulation
- [NIRFASTer](https://github.com/nirfaster/NIRFASTer), for FEM-based photon simulation

## Planned future toolboxes
- [MNE](https://mne.tools/stable/index.html), for state of the art EEG/MEG processing functionality
- [NeuroKit](https://github.com/neuropsychology/NeuroKit), for Neurophysiological Signal Processing
- [...?](https://openfnirs.org/software/)